JasonWoof Got questions, comments, patches, etc.? Contact Jason Woofenden
separated layout-specific stuff into separate .h and .c files which are included...
[dwm.git] / dwm.h
diff --git a/dwm.h b/dwm.h
index a6af9ba..c2f1e7e 100644 (file)
--- a/dwm.h
+++ b/dwm.h
@@ -1,5 +1,4 @@
-/* (C)opyright MMVI-MMVII Anselm R. Garbe <garbeam at gmail dot com>
- * See LICENSE file for license details.
+/* See LICENSE file for copyright and license details.
  *
  * dynamic window manager is designed like any other X client as well. It is
  * driven through handling X events. In contrast to other X clients, a window
 /* mask shorthands, used in event.c and client.c */
 #define BUTTONMASK             (ButtonPressMask | ButtonReleaseMask)
 
-enum { NetSupported, NetWMName, NetLast };             /* EWMH atoms */
-enum { WMProtocols, WMDelete, WMState, WMLast };       /* default atoms */
+enum { BarTop, BarBot, BarOff };                       /* bar position */
 enum { CurNormal, CurResize, CurMove, CurLast };       /* cursor */
 enum { ColBorder, ColFG, ColBG, ColLast };             /* color */
-
-typedef union {
-       const char *cmd;
-       int i;
-} Arg; /* argument type */
-
-typedef struct {
-       int ascent;
-       int descent;
-       int height;
-       XFontSet set;
-       XFontStruct *xfont;
-} Fnt;
-
-typedef struct {
-       int x, y, w, h;
-       unsigned long norm[ColLast];
-       unsigned long sel[ColLast];
-       Drawable drawable;
-       Fnt font;
-       GC gc;
-} DC; /* draw context */
+enum { NetSupported, NetWMName, NetLast };             /* EWMH atoms */
+enum { WMProtocols, WMDelete, WMState, WMLast };       /* default atoms */
 
 typedef struct Client Client;
 struct Client {
@@ -69,10 +47,11 @@ struct Client {
        int x, y, w, h;
        int rx, ry, rw, rh; /* revert geometry */
        int basew, baseh, incw, inch, maxw, maxh, minw, minh;
-       int minax, minay, maxax, maxay;
+       int minax, maxax, minay, maxay;
+       int unmapped;
        long flags; 
-       unsigned int border;
-       Bool isbanned, isfixed, ismax, isversatile;
+       unsigned int border, oldborder;
+       Bool isbanned, isfixed, ismax, isfloating;
        Bool *tags;
        Client *next;
        Client *prev;
@@ -81,6 +60,21 @@ struct Client {
 };
 
 typedef struct {
+       int x, y, w, h;
+       unsigned long norm[ColLast];
+       unsigned long sel[ColLast];
+       Drawable drawable;
+       GC gc;
+       struct {
+               int ascent;
+               int descent;
+               int height;
+               XFontSet set;
+               XFontStruct *xfont;
+       } font;
+} DC; /* draw context */
+
+typedef struct {
        const char *symbol;
        void (*arrange)(void);
 } Layout;
@@ -89,8 +83,8 @@ extern const char *tags[];                    /* all tags */
 extern char stext[256];                                /* status text */
 extern int screen, sx, sy, sw, sh;             /* screen geometry */
 extern int wax, way, wah, waw;                 /* windowarea geometry */
-extern unsigned int bh, blw;                   /* bar height, bar layout label width */
-extern unsigned int ntags, numlockmask;                /* number of tags, dynamic lock mask */
+extern unsigned int bh, blw, bpos;             /* bar height, bar layout label width, bar position */
+extern unsigned int ntags, numlockmask;                /* number of tags, numlock mask */
 extern void (*handler[LASTEvent])(XEvent *);   /* event handler */
 extern Atom wmatom[WMLast], netatom[NetLast];
 extern Bool selscreen, *seltag;                        /* seltag is array of Bool */
@@ -102,57 +96,52 @@ extern Layout *lt;
 extern Window root, barwin;
 
 /* client.c */
-extern void attach(Client *c);                 /* attaches c to global client list */
-extern void configure(Client *c);              /* send synthetic configure event */
-extern void detach(Client *c);                 /* detaches c from global client list */
-extern void focus(Client *c);                  /* focus c, c may be NULL */
-extern void killclient(Arg arg);               /* kill c nicely */
-extern void manage(Window w, XWindowAttributes *wa);   /* manage new client */
-extern void resize(Client *c, int x, int y,
+void attach(Client *c);                        /* attaches c to global client list */
+void ban(Client *c);                   /* bans c */
+void configure(Client *c);             /* send synthetic configure event */
+void detach(Client *c);                        /* detaches c from global client list */
+void focus(Client *c);                 /* focus c if visible && !NULL, or focus top visible */
+void killclient(const char *arg);      /* kill sel  nicely */
+void manage(Window w, XWindowAttributes *wa);  /* manage new client */
+void resize(Client *c, int x, int y,
                int w, int h, Bool sizehints);  /* resize with given coordinates c*/
-extern void toggleversatile(Arg arg);          /* toggles focused client between versatile/and non-versatile state */
-extern void updatesizehints(Client *c);                /* update the size hint variables of c */
-extern void updatetitle(Client *c);            /* update the name of c */
-extern void unmanage(Client *c);               /* destroy c */
+void togglefloating(const char *arg);  /* toggles sel between floating/tiled state */
+void unban(Client *c);                 /* unbans c */
+void unmanage(Client *c);              /* destroy c */
+void updatesizehints(Client *c);       /* update the size hint variables of c */
+void updatetitle(Client *c);           /* update the name of c */
 
 /* draw.c */
-extern void drawstatus(void);                  /* draw the bar */
-extern void drawtext(const char *text,
-               unsigned long col[ColLast]);    /* draw text */
-extern unsigned int textw(const char *text);   /* return the width of text in px*/
+void drawstatus(void);                 /* draw the bar */
+void drawtext(const char *text, unsigned long col[ColLast]);   /* draw text */
+unsigned int textw(const char *text);  /* return the width of text in px*/
 
 /* event.c */
-extern void grabkeys(void);                    /* grab all keys defined in config.h */
+void grabkeys(void);                   /* grab all keys defined in config.h */
 
 /* layout.c */
-extern void focusnext(Arg arg);                /* focuses next visible client, arg is ignored  */
-extern void focusprev(Arg arg);                /* focuses previous visible client, arg is ignored */
-extern void incmasterw(Arg arg);               /* increments the master width with arg's index value */
-extern void incnmaster(Arg arg);               /* increments nmaster with arg's index value */
-extern void initlayouts(void);                 /* initialize layout array */
-extern Client *nexttiled(Client *c);           /* returns tiled successor of c */
-extern void restack(void);                     /* restores z layers of all clients */
-extern void setlayout(Arg arg);                /* sets layout, -1 toggles */
-extern void togglemax(Arg arg);                        /* toggles maximization of versatile client */
-extern void versatile(void);                   /* arranges all windows versatile */
+void focusclient(const char *arg);     /* focuses next(1)/previous(-1) visible client */
+void initlayouts(void);                        /* initialize layout array */
+Client *nexttiled(Client *c);          /* returns tiled successor of c */
+void restack(void);                    /* restores z layers of all clients */
+void setlayout(const char *arg);       /* sets layout, NULL means next layout */
+void togglebar(const char *arg);       /* shows/hides the bar */
 
 /* main.c */
-extern void quit(Arg arg);                     /* quit dwm nicely */
-extern void sendevent(Window w, Atom a, long value);   /* send synthetic event to w */
-extern int xerror(Display *dsply, XErrorEvent *ee);    /* dwm's X error handler */
+void updatebarpos(void);               /* updates the bar position */
+void quit(const char *arg);            /* quit dwm nicely */
+int xerror(Display *dsply, XErrorEvent *ee);   /* dwm's X error handler */
 
 /* tag.c */
-extern void compileregs(void);                 /* initialize regexps of rules defined in config.h */
-extern Bool isvisible(Client *c);              /* returns True if client is visible */
-extern void settags(Client *c, Client *trans); /* sets tags of c */
-extern void tag(Arg arg);                      /* tags c with arg's index */
-extern void toggletag(Arg arg);                /* toggles c tags with arg's index */
-extern void toggleview(Arg arg);               /* toggles the tag with arg's index (in)visible */
-extern void view(Arg arg);                     /* views the tag with arg's index */
-extern void zoom(Arg arg);                     /* zooms the focused client to master area, arg is ignored */
+void compileregs(void);                        /* initialize regexps of rules defined in config.h */
+Bool isvisible(Client *c);             /* returns True if client is visible */
+void settags(Client *c, Client *trans);        /* sets tags of c */
+void tag(const char *arg);             /* tags sel with arg's index */
+void toggletag(const char *arg);       /* toggles sel tags with arg's index */
+void toggleview(const char *arg);      /* toggles the tag with arg's index (in)visible */
+void view(const char *arg);            /* views the tag with arg's index */
 
 /* util.c */
-extern void *emallocz(unsigned int size);      /* allocates zero-initialized memory, exits on error */
-extern void eprint(const char *errstr, ...);   /* prints errstr and exits with 1 */
-extern void spawn(Arg arg);                    /* forks a new subprocess with arg's cmd */
-
+void *emallocz(unsigned int size);     /* allocates zero-initialized memory, exits on error */
+void eprint(const char *errstr, ...);  /* prints errstr and exits with 1 */
+void spawn(const char *arg);           /* forks a new subprocess with arg's cmd */